/**********************************************************************
 * File Name: RadsimStatus.java
 *
 * Copyright (C) 2000, US Air Force Research Laboratory,
 * Rome Research Site, Rome NY 13424, USA.
 *
 * Use of this software implies acceptance of the terms described in
 * accompanying license.txt file.
 *
 *
 * Authors: James Lawton, Jennifer Dzek, John Crowter,
 *          Bob Paragi, and Joe Beasock
 *
 * Creation Date: Feb 2000
 *
 * Description: The status canvas for the graphics for the
 * RadSim simulation.
 *
 * Modification History:
 *
 **********************************************************************/

import java.util.*;
import java.awt.*;
import java.awt.event.*;

public class RadsimStatus extends Canvas
{
    public SimEnvironment env;

    protected Image offscreen; /** We use page flipping to avoid flickering */
    protected Dimension offscreensize;
    protected java.awt.Graphics offgraphics;
    private Color bgColor;

    public RadsimStatus () {
	offscreen = null;
	bgColor = new Color(135, 206, 250); //LightSkyBlue
    }

    public void update(Graphics g) {
	String radsimStatus = "Running";
	String debugLevel = "None";
  	Dimension d = getSize();

 	if ((offscreen == null) || (d.width != 	offscreensize.width) ||
 	    (d.height != offscreensize.height)) {
 	    offscreen = createImage(d.width, d.height);
 	    offscreensize = d;
 	    offgraphics = offscreen.getGraphics();
 	    offgraphics.setFont(getFont());
 	}
 	offgraphics.setColor(bgColor);
 	offgraphics.fillRect(0,0,d.width, d.height);

	if (env.running) radsimStatus = "Running";
	else radsimStatus = "Stopped";

	switch(env.Debug) {
	case 0:
	    debugLevel = "None";
	    break;
	case 1:
	    debugLevel = "Basic";
	    break;
	case 2:
	    debugLevel = "Advanced";
	    break;
	case 3:
	    debugLevel = "Complete";
	    break;
	}


	offgraphics.setColor(Color.black);
  	offgraphics.drawString("SimTime: " + (env.clock.simtime * env.clock.ticksize) +
			       ",          Status: " + radsimStatus +
			       ",          Debug Level: " + debugLevel,
			       20, 20);

	g.drawImage(offscreen,0,0,null);

    }

}
